Citing ytree
============

If you use ytree in your work, please cite the following:

Smith et al., (2019). ytree: A Python package for analyzing merger
trees. Journal of Open Source Software, 4(44), 1881,
https://doi.org/10.21105/joss.01881

For BibTeX users:

::

  @article{ytree,
    doi = {10.21105/joss.01881},
    url = {https://doi.org/10.21105/joss.01881},
    year  = {2019},
    month = {dec},
    publisher = {The Open Journal},
    volume = {4},
    number = {44},
    pages = {1881},
    author = {Britton D. Smith and Meagan Lang},
    title = {ytree: A Python package for analyzing merger trees},
    journal = {Journal of Open Source Software}
  }

If you would like to also cite the specific version of ``ytree`` used in
your work, include the following reference:

::

  @software{britton_smith_2023_8349044,
    author       = {Britton Smith and
                    Meagan Lang and
                    John Wise and
                    Juanjo Bazán},
    title        = {ytree-project/ytree: ytree 3.2.1 Release},
    month        = sep,
    year         = 2023,
    publisher    = {Zenodo},
    version      = {ytree-3.2.1},
    doi          = {10.5281/zenodo.8349044},
    url          = {https://doi.org/10.5281/zenodo.8349044}
  }
